@@ -33,5 +33,3 @@ class ESDocument(BaseModel):
     rights: Optional[str] = f"Copyright {date.today().year}, NAV"
     content: Optional[dict] = {}
     url: Optional[str] = ""
-    resources: Optional[List[dict]] = []
-    views: Optional[List[dict]] = []
